Crate ristretto_gc

Crate ristretto_gc 

Ristretto GC

Code Coverage Benchmarks License Semantic Versioning

A low pause, concurrent and parallel mark and sweep garbage collector implementation for the Ristretto VM. This crate provides Gc<T> types for garbage collected references, using a pure reachability analysis algorithm with automatic cycle detection and collection.

Modules

sync
Cross-target synchronization primitives.

Structs

Configuration
Configuration for the garbage collector
ConfigurationBuilder
Builder for creating a Configuration with a fluent interface.
GarbageCollector
A low pause, parallel, concurrent garbage collector using reachability analysis.
Gc
A garbage collected pointer type for T.
GcRootGuard
RAII guard for managing garbage collector root references.
Statistics
Statistics about garbage collection performance

Enums

Error
Errors that can occur during garbage collection and memory management.

Traits

Finalize
Trait for objects that need custom finalization before being dropped.
Trace
Trait for objects that can be traced by the garbage collector.

Type Aliases

Result
Ristretto Garbage Collector result type