Ristretto GC
A low pause, concurrent and parallel mark and sweep garbage collector implementation for the
Ristretto VM. This crate provides Gc<T> types for garbage collected references, using a pure
reachability analysis algorithm with automatic cycle detection and collection.
Modules
- sync
- Cross-target synchronization primitives.
Structs
- Configuration
- Configuration for the garbage collector
- Configuration
Builder - Builder for creating a
Configurationwith a fluent interface. - Garbage
Collector - A low pause, parallel, concurrent garbage collector using reachability analysis.
- Gc
- A garbage collected pointer type for
T. - GcRoot
Guard - RAII guard for managing garbage collector root references.
- Statistics
- Statistics about garbage collection performance
Enums
- Error
- Errors that can occur during garbage collection and memory management.
Traits
- Finalize
- Trait for objects that need custom finalization before being dropped.
- Trace
- Trait for objects that can be traced by the garbage collector.
Type Aliases
- Result
- Ristretto Garbage Collector result type